;; Generated package description from project.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "project" "0.11.2.0.20260612.29" "Operations on the current project" '((emacs "26.1") (xref "1.7.0")) :commit "568a435af920fdf0bf7166661bb10bcad685109a" :url "https://elpa.gnu.org/packages/project.html")
